@@ -3,7 +3,7 @@ BEGIN {
   $Spreadsheet::ParseXLSX::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Spreadsheet::ParseXLSX::VERSION = '0.09';
+  $Spreadsheet::ParseXLSX::VERSION = '0.10';
 }
 use strict;
 use warnings;
@@ -73,7 +73,8 @@ sub _parse_workbook {
     $workbook->{FormatStr} = $styles->{FormatStr};
     $workbook->{Font}      = $styles->{Font};
 
-    $workbook->{PkgStr} = $self->_parse_shared_strings($files->{strings});
+    $workbook->{PkgStr} = $self->_parse_shared_strings($files->{strings})
+        if $files->{strings};
 
     # $workbook->{StandardWidth} = ...;
 
@@ -150,10 +151,11 @@ sub _parse_sheet {
 
     for my $cell (@cells) {
         my ($row, $col) = $self->_cell_to_row_col($cell->att('r'));
-        my $val = $cell->first_child('v')
-            ? $cell->first_child('v')->text
-            : undef;
         my $type = $cell->att('t') || 'n';
+        my $val_xml = $type eq 'inlineStr'
+            ? $cell->first_child('is')->first_child('t')
+            : $cell->first_child('v');
+        my $val = $val_xml ? $val_xml->text : undef;
 
         my $long_type;
         if (!defined($val)) {
@@ -178,7 +180,7 @@ sub _parse_sheet {
         elsif ($type eq 'e') {
             $long_type = 'Text';
         }
-        elsif ($type eq 'str') {
+        elsif ($type eq 'str' || $type eq 'inlineStr') {
             $long_type = 'Text';
         }
         else {
@@ -526,12 +528,9 @@ sub _extract_files {
         $zip,
         $self->_rels_for($wb_name)
     );
-    my $strings_xml = $self->_parse_xml(
-        $zip,
-        $path_base . ($wb_rels->find_nodes(
-            qq<//Relationship[\@Type="$type_base/sharedStrings"]>
-        ))[0]->att('Target')
-    );
+    my ($strings_xml) = map {
+        $self->_parse_xml($zip, $path_base . $_->att('Target'))
+    } $wb_rels->find_nodes(qq<//Relationship[\@Type="$type_base/sharedStrings"]>);
     my $styles_xml = $self->_parse_xml(
         $zip,
         $path_base . ($wb_rels->find_nodes(
@@ -549,10 +548,12 @@ sub _extract_files {
 
     return {
         workbook => $wb_xml,
-        strings  => $strings_xml,
         styles   => $styles_xml,
         sheets   => \%worksheet_xml,
         themes   => \%themes_xml,
+        ($strings_xml
+            ? (strings => $strings_xml)
+            : ()),
     };
 }
 
@@ -676,7 +677,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
